@@ -18,7 +18,12 @@ def calcCandlesSimilarity(candles0: trdb2py.trading2_pb2.Candles, candles1: trdb
 
     arr = []
     for i in range(len(arr0)):
-        arr.append(arr1[i] / arr0[i])
+        if arr1[i] == arr0[i]:
+            arr.append(1)
+        elif arr0[i] > arr1[i]:
+            arr.append(arr1[i] / arr0[i])
+        elif arr1[i] > arr0[i]:
+            arr.append(arr0[i] / arr1[i])
 
     return np.mean(arr)
 
@@ -100,4 +105,4 @@ def calcCandlesSimilarity_LowLevel2(candles0: trdb2py.trading2_pb2.Candles, cand
             else:
                 cv += abs(arrv1[i]) / abs(arrv0[i])
 
-    return (nums / len(arr0)) * (cv / nums)
\ No newline at end of file
+    return (cv / nums)
\ No newline at end of file
